LinkInfo class abstract

Encapsulates all the information necessary to build a Link widget.

Constructors

LinkInfo()

Properties

builder → LinkWidgetBuilder
Called at build time to construct the widget tree under the link.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isDisabled → bool
Whether the link is disabled or not.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → LinkTarget
The target indicating where to open the link.
no setter
uri → Uri?
The destination that this link leads to.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited